@@ -1,7 +1,7 @@
 
 "profile.evd" <-  function(fitted, which = names(fitted$estimate), conf = 0.999, mesh = fitted$std.err[which]/4, xmin = rep(-Inf, length(which)), xmax = rep(Inf, length(which)), convergence = FALSE, method = "BFGS", control = list(maxit = 500), ...)
 {
-    if(!inherits(fitted, "evd")) 
+    if(!inherits(fitted, "evd"))
         stop("Use only with `evd' objects")
     if(inherits(fitted, "extreme"))
         stop("profiles not implemented for this model")
@@ -20,7 +20,7 @@
     prof.list <- as.list(numeric(length(which)))
     names(xmin) <- names(xmax) <- names(prof.list) <- which
     if(is.null(names(mesh))) names(mesh) <- which
-    mles <- fitted$estimate[which]                   
+    mles <- fitted$estimate[which]
     for(j in which) {
         print(paste("profiling",j))
         prof1 <- prof2 <- matrix(nrow = 0, ncol = length(fitted$estimate) + 1)
@@ -36,6 +36,10 @@
         if(inherits(fitted, "gev")) {
             call.args$nsloc <- fitted$nsloc
             call.args$prob <- fitted$prob
+        }
+		if(inherits(fitted, "gumbelx")) {
+            call.args$nsloc1 <- fitted$nsloc1
+            call.args$nsloc2 <- fitted$nsloc2
         }
         if(inherits(fitted, "pot")) {
             call.args$threshold <- fitted$threshold
@@ -54,7 +58,7 @@
             call.args$sym <- fitted$sym
             call.args$cloc <- fitted$cmar[1]
             call.args$cscale <- fitted$cmar[2]
-            call.args$cshape <- fitted$cmar[3] 
+            call.args$cshape <- fitted$cmar[3]
         }
         if(inherits(fitted, "bvpot")) {
             call.args$threshold <- fitted$threshold
@@ -62,12 +66,12 @@
             call.args$model <- fitted$model
             call.args$sym <- fitted$sym
             call.args$cscale <- fitted$cmar[1]
-            call.args$cshape <- fitted$cmar[2]          
+            call.args$cshape <- fitted$cmar[2]
         }
         lcnt <- TRUE; ppar <- mles[j]
         while(lcnt) {
             ppar <- as.vector(ppar + mesh[j])
-            if(ppar >= xmax[j]) ppar <- as.vector(xmax[j])      
+            if(ppar >= xmax[j]) ppar <- as.vector(xmax[j])
             call.args[[j]] <- ppar
             fit.mod <- do.call(call.fn, call.args)
             if(convergence) print(fit.mod$convergence)
@@ -95,7 +99,7 @@
         prof2 <- prof2[nrow(prof2):1, ,drop = FALSE]
         prof <- rbind(prof2, rop, prof1)
         rownames(prof) <- NULL
-        
+
         rdev <- qchisq(conf, 1) + fitted$deviance
         if(prof[1, "deviance"] == 2e6)  {
           prof <- prof[-1, ,drop = FALSE]
@@ -114,18 +118,18 @@
     structure(prof.list, deviance = fitted$deviance,
               xmin = xmin, xmax = xmax, class = "profile.evd")
 }
-    
+
 profile2d <- function (fitted, ...) {
     UseMethod("profile2d")
 }
 
 "profile2d.evd" <-  function(fitted, prof, which, pts = 20, convergence = FALSE, method = "Nelder-Mead", control = list(maxit = 5000), ...)
 {
-    if(!inherits(fitted, "evd")) 
+    if(!inherits(fitted, "evd"))
         stop("Use only with `evd' objects")
     if(inherits(fitted, "extreme"))
         stop("profiles not implemented for this model")
-    if (!inherits(prof, "profile.evd")) 
+    if (!inherits(prof, "profile.evd"))
         stop("`prof' must be a `profile.evd' object")
     if(length(fitted$estimate) < 3)
         stop("Cannot profile two dimensional likelihood")
@@ -141,7 +145,7 @@ profile2d <- function (fitted, ...) {
     names(prof.list) <- c("trace", which)
     limits1 <- range(prof[[which[1]]][,1])
     limits2 <- range(prof[[which[2]]][,1])
-    mles <- fitted$estimate[which]                   
+    mles <- fitted$estimate[which]
     prof <- matrix(NA, nrow = pts^2, ncol = length(fitted$estimate) + 1)
     parvec1 <- seq(limits1[1], limits1[2], length = pts)
     prof.list[[which[1]]] <- parvec1
@@ -161,6 +165,10 @@ profile2d <- function (fitted, ...) {
     if(inherits(fitted, "gev")) {
         call.args$nsloc <- fitted$nsloc
         call.args$prob <- fitted$prob
+    }
+	if(inherits(fitted, "gumbelx")) {
+        call.args$nsloc1 <- fitted$nsloc1
+        call.args$nsloc2 <- fitted$nsloc2
     }
     #if(inherits(fitted, "pot")) {
     #    call.args$threshold <- fitted$threshold
@@ -187,7 +195,7 @@ profile2d <- function (fitted, ...) {
         call.args$model <- fitted$model
         call.args$sym <- fitted$sym
         call.args$cscale <- fitted$cmar[1]
-        call.args$cshape <- fitted$cmar[2]          
+        call.args$cshape <- fitted$cmar[2]
     }
     for(i in 1:pts^2) {
         call.args[[which[1]]] <- pars[i,1]
@@ -208,9 +216,9 @@ profile2d <- function (fitted, ...) {
 
 "plot.profile.evd" <-  function(x, which = names(x), main = NULL,
      ask = nb.fig < length(which) && dev.interactive(), ci = 0.95,
-     clty = 2, ...) 
+     clty = 2, ...)
 {
-    if (!inherits(x, "profile.evd")) 
+    if (!inherits(x, "profile.evd"))
         stop("Use only with `profile.evd' objects")
     if(!is.character(which))
         stop("`which' must be a character vector")
@@ -239,7 +247,7 @@ profile2d <- function (fitted, ...) {
 
 "confint.profile.evd" <- function(object, parm, level = 0.95, ...)
 {
-    if(missing(parm)) 
+    if(missing(parm))
       parm <- names(object)
     if(!all(parm %in% names(object)))
       stop("`parm' contains unprofiled parameters")
@@ -266,14 +274,14 @@ profile2d <- function (fitted, ...) {
       }
       if(x[n,"deviance"] <= rdev && th.u) ci[i,2] <- x[n, 1]
       if(x[n,"deviance"] > rdev)
-        ci[i,2] <- approx(x[!halves,2], x[!halves,1], xout = rdev)$y 
+        ci[i,2] <- approx(x[!halves,2], x[!halves,1], xout = rdev)$y
     }
     ci
 }
 
 "plot.profile2d.evd" <-  function(x, main = NULL, ci = c(0.5,0.8,0.9,0.95,0.975, 0.99, 0.995), col = heat.colors(8), intpts = 75, xaxs = "r", yaxs = "r", ...)
 {
-    if (!inherits(x, "profile2d.evd")) 
+    if (!inherits(x, "profile2d.evd"))
         stop("Use only with `profile2d.evd' objects")
     which <- names(x)[2:3]
     if(is.null(main)) {
@@ -289,8 +297,8 @@ profile2d <- function (fitted, ...) {
     prof <- -prof/2
     br.pts <- (-br.pts/2)[length(br.pts):1]
     col <- col[length(col):1]
-    
-    if(!requireNamespace("akima", quietly = TRUE)) {
+
+    if(!requireNamespace("interp", quietly = TRUE)) {
         image(x[[which[1]]], x[[which[2]]],
               matrix(prof, nrow = length(x[[which[1]]])),
               col = col, breaks = c(-1e6+1, br.pts),
@@ -299,8 +307,8 @@ profile2d <- function (fitted, ...) {
     }
     else {
         lim1 <- range(x[[which[1]]])
-        lim2 <- range(x[[which[2]]]) 
-        prof.interp <- akima::interp(x$trace[,1], x$trace[,2], prof,
+        lim2 <- range(x[[which[2]]])
+        prof.interp <- interp::interp(x$trace[,1], x$trace[,2], prof,
             xo = seq(lim1[1], lim1[2], length = intpts),
             yo = seq(lim2[1], lim2[2], length = intpts))
         image(prof.interp, col = col, breaks = c(min(prof), br.pts),
